@@ -3,11 +3,19 @@ use std::collections::HashMap;
 use crate::{DefaultModifiers, sp};
 use crate::{Renderable};
 
+#[derive(Debug, Clone)]
+pub enum Size {
+    Normal,
+    Large,
+    XLarge
+}
+
 #[derive(Debug, Clone)]
 pub struct Avatar {
     node: Node,
     name: String,
     profil_img: Option<String>,
+    size: Size
 }
 
 impl Avatar {
@@ -15,9 +23,15 @@ impl Avatar {
         Self {
             node: Default::default(),
             name: name.to_string(),
-            profil_img: profil_img.map(|url| url.to_string())
+            profil_img: profil_img.map(|url| url.to_string()),
+            size: Size::Normal
         }
     }
+
+    pub fn size(&mut self, size: Size) -> Self {
+        self.size = size;
+        self.clone()
+    }
 }
 
 impl NodeContainer for Avatar {
@@ -32,7 +46,11 @@ impl Renderable for Avatar {
     fn render(&self) -> Node {
         let mut avatar = self.clone()
             .add_class("avatar")
-            .add_class("avatar--normal");
+            .add_class(&format!("avatar--{}", match self.size {
+                Size::Normal => "normal",
+                Size::Large => "large",
+                Size::XLarge => "x-large",
+            }));
         if let Some(profile_img) = self.profil_img.clone()  {
             avatar = avatar.background_image(&profile_img);
         } else {
